@@ -73,9 +73,6 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('ovs/resource_provider_default_hypervisor').\
         with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('network_log/rate_limit').with_value('<SERVICE DEFAULT>')
-      should contain_neutron_agent_ovs('network_log/burst_limit').with_value('<SERVICE DEFAULT>')
-      should contain_neutron_agent_ovs('network_log/local_output_log_base').with_value('<SERVICE DEFAULT>')
     end
 
     it 'installs neutron ovs agent package' do
